@@ -169,7 +169,7 @@ fx.total <- function (object, sessnum = 1, mask = NULL, ncores = NULL, ...)
 ###############################################################################
 
 allhistfxi <- function (m, realparval, haztemp, gkhk, pi.density, PIA, usge,
-                        CH, binomN, grp, pmixn, grain) {
+                        CH, binomN, grp, pmixn, grain, ncores) {
     nc <- nrow(CH)
     nmix <- nrow(pmixn)
     sump <- matrix(0, nrow = nc, ncol = m)
@@ -178,31 +178,32 @@ allhistfxi <- function (m, realparval, haztemp, gkhk, pi.density, PIA, usge,
         hi <- if (any(binomN==-2)) haztemp$hindex else -1                   ## index to hx
    
         temp <- simplehistoriesfxicpp(
-            as.integer(x-1),
-            as.integer(m),
-            as.integer(nc),
-            as.integer(nrow(realparval)),
-            as.integer(grain),
-            as.integer(binomN),
-            as.integer(CH),   
-            as.integer(grp)-1L,
-            as.double (gkhk$gk),     ## precomputed probability 
-            as.double (gkhk$hk),     ## precomputed hazard
-            as.matrix (pi.density),
-            as.integer(PIA),
-            as.matrix(usge),
-            as.matrix (hx),                
-            as.matrix (hi))
+          as.integer(x-1),
+          as.integer(m),
+          as.integer(nc),
+          as.integer(nrow(realparval)),
+          as.integer(grain),
+          as.integer(ncores),
+          as.integer(binomN),
+          as.integer(CH),   
+          as.integer(grp)-1L,
+          as.double (gkhk$gk),     ## precomputed probability 
+          as.double (gkhk$hk),     ## precomputed hazard
+          as.matrix (pi.density),
+          as.integer(PIA),
+          as.matrix(usge),
+          as.matrix (hx),                
+          as.matrix (hi))
         sump <- sump + sweep(temp, MARGIN=1, STATS = pmixn[x,], FUN = "*")
     }
     sump
 }
 
 allhistpolygonfxi <- function (detectfn, realparval, haztemp, hk, H, pi.density, PIA, 
-                               CH, xy, binomNcode, grp, usge, mask, pmixn, maskusage, 
-                               grain, minprob) {
-    nc <- nrow(CH)
-    nmix <- nrow(pmixn)
+  CH, xy, binomNcode, grp, usge, mask, pmixn, maskusage, 
+  grain, ncores, minprob) {
+  nc <- nrow(CH)
+  nmix <- nrow(pmixn)
     m <- length(pi.density)
     s <- ncol(usge)
     sump <- matrix(0, nrow = nc, ncol = m)
@@ -212,8 +213,9 @@ allhistpolygonfxi <- function (detectfn, realparval, haztemp, hk, H, pi.density,
         temp <- polygonfxicpp(
             as.integer(nc),
             as.integer(detectfn[1]),
-            as.integer(grain),
-            as.double(minprob),          
+          as.integer(grain),
+          as.integer(ncores),
+          as.double(minprob),          
             as.integer(binomNcode),   # vector length s
             as.integer(CH),   
             as.matrix(xy$xy),
@@ -281,7 +283,8 @@ fxi.secr <- function (object, i = NULL, sessnum = 1, X = NULL, ncores = NULL) {
   }
   grp <- data$grp[ok]
 
-  setNumThreads(ncores)
+  ncores <- setNumThreads(ncores)
+  grain <- if (ncores==1) 0 else 1;
   
   #----------------------------------------
   # Density
@@ -339,20 +342,20 @@ fxi.secr <- function (object, i = NULL, sessnum = 1, X = NULL, ncores = NULL) {
                           object$parindx, object$details$cutval)
 
   gkhk <- makegk (data$dettype, object$detectfn, data$traps, data$mask, object$details, sessnum, 
-                  NE, D, miscparm, Xrealparval)
+                  NE, D, miscparm, Xrealparval, grain, ncores)
   haztemp <- gethazard (data$m, data$binomNcode, nrow(realparval), gkhk$hk, PIA, data$usge)
   
   ## 2020-01-26 conditional on point vs polygon detectors
   if (data$dettype[1] %in% c(0,1,2,5,8,13)) {
       
       prmat <- allhistfxi (data$m, Xrealparval, haztemp, gkhk, pimask, PIA, data$usge,
-                           CH, data$binomNcode, grp, pmix, object$details$grain)
+                           CH, data$binomNcode, grp, pmix, grain, ncores)
   }
   else {
       # warning ("fxi.secr experimental for polygon detector types")
       prmat <- allhistpolygonfxi (object$detectfn, Xrealparval, haztemp, gkhk$hk, gkhk$H, pimask, PIA, 
           CH, xy, data$binomNcode, grp, data$usge, data$mask,
-          pmix, data$maskusage, object$details$grain, object$details$minprob)
+          pmix, data$maskusage, grain, ncores, object$details$minprob)
   }
   
   pisum <- apply(prmat,1,sum)
@@ -362,13 +365,14 @@ fxi.secr <- function (object, i = NULL, sessnum = 1, X = NULL, ncores = NULL) {
   }
   else {
     nX <- nrow(X)
-    gkhkX <- makegk (data$dettype, object$detectfn, data$traps, X, object$details, sessnum, NE, D, miscparm, Xrealparval)
+    gkhkX <- makegk (data$dettype, object$detectfn, data$traps, X, object$details, 
+        sessnum, NE, D, miscparm, Xrealparval, grain, ncores)
     haztempX <- gethazard (nX, data$binomNcode, nrow(realparval), gkhkX$hk, PIA, data$usge)
     
     if (data$dettype[1] %in% c(0,1,2,5,8,13)) {
         ## point detectors
         prmatX <- allhistfxi (nX, Xrealparval, haztempX, gkhkX, piX, PIA, data$usge,
-                          CH, data$binomNcode, grp, pmix, object$details$grain)
+                          CH, data$binomNcode, grp, pmix, object$details$grain, ncores)
     }
     else {
         ## polygon-like detectors
